@@ -16,15 +16,15 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -33,14 +33,16 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.apigateway_v1.services.api_gateway_service import pagers
-from google.cloud.apigateway_v1.types import apigateway
 from google.protobuf import empty_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import ApiGatewayServiceTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import ApiGatewayServiceGrpcAsyncIOTransport
+
+from google.cloud.apigateway_v1.services.api_gateway_service import pagers
+from google.cloud.apigateway_v1.types import apigateway
+
 from .client import ApiGatewayServiceClient
+from .transports.base import DEFAULT_CLIENT_INFO, ApiGatewayServiceTransport
+from .transports.grpc_asyncio import ApiGatewayServiceGrpcAsyncIOTransport
 
 
 class ApiGatewayServiceAsyncClient:
@@ -238,9 +240,9 @@ class ApiGatewayServiceAsyncClient:
 
             from google.cloud import apigateway_v1
 
-            def sample_list_gateways():
+            async def sample_list_gateways():
                 # Create a client
-                client = apigateway_v1.ApiGatewayServiceClient()
+                client = apigateway_v1.ApiGatewayServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = apigateway_v1.ListGatewaysRequest(
@@ -251,7 +253,7 @@ class ApiGatewayServiceAsyncClient:
                 page_result = client.list_gateways(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -312,12 +314,20 @@ class ApiGatewayServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListGatewaysAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -338,9 +348,9 @@ class ApiGatewayServiceAsyncClient:
 
             from google.cloud import apigateway_v1
 
-            def sample_get_gateway():
+            async def sample_get_gateway():
                 # Create a client
-                client = apigateway_v1.ApiGatewayServiceClient()
+                client = apigateway_v1.ApiGatewayServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = apigateway_v1.GetGatewayRequest(
@@ -348,7 +358,7 @@ class ApiGatewayServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_gateway(request=request)
+                response = await client.get_gateway(request=request)
 
                 # Handle the response
                 print(response)
@@ -412,7 +422,12 @@ class ApiGatewayServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -431,14 +446,13 @@ class ApiGatewayServiceAsyncClient:
         r"""Creates a new Gateway in a given project and
         location.
 
-
         .. code-block:: python
 
             from google.cloud import apigateway_v1
 
-            def sample_create_gateway():
+            async def sample_create_gateway():
                 # Create a client
-                client = apigateway_v1.ApiGatewayServiceClient()
+                client = apigateway_v1.ApiGatewayServiceAsyncClient()
 
                 # Initialize request argument(s)
                 gateway = apigateway_v1.Gateway()
@@ -455,7 +469,7 @@ class ApiGatewayServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -530,7 +544,8 @@ class ApiGatewayServiceAsyncClient:
                 maximum=60.0,
                 multiplier=2,
                 predicate=retries.if_exception_type(
-                    core_exceptions.ServiceUnavailable, core_exceptions.Unknown,
+                    core_exceptions.ServiceUnavailable,
+                    core_exceptions.Unknown,
                 ),
                 deadline=60.0,
             ),
@@ -545,7 +560,12 @@ class ApiGatewayServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -574,9 +594,9 @@ class ApiGatewayServiceAsyncClient:
 
             from google.cloud import apigateway_v1
 
-            def sample_update_gateway():
+            async def sample_update_gateway():
                 # Create a client
-                client = apigateway_v1.ApiGatewayServiceClient()
+                client = apigateway_v1.ApiGatewayServiceAsyncClient()
 
                 # Initialize request argument(s)
                 gateway = apigateway_v1.Gateway()
@@ -591,7 +611,7 @@ class ApiGatewayServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -660,7 +680,8 @@ class ApiGatewayServiceAsyncClient:
                 maximum=60.0,
                 multiplier=2,
                 predicate=retries.if_exception_type(
-                    core_exceptions.ServiceUnavailable, core_exceptions.Unknown,
+                    core_exceptions.ServiceUnavailable,
+                    core_exceptions.Unknown,
                 ),
                 deadline=60.0,
             ),
@@ -677,7 +698,12 @@ class ApiGatewayServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -705,9 +731,9 @@ class ApiGatewayServiceAsyncClient:
 
             from google.cloud import apigateway_v1
 
-            def sample_delete_gateway():
+            async def sample_delete_gateway():
                 # Create a client
-                client = apigateway_v1.ApiGatewayServiceClient()
+                client = apigateway_v1.ApiGatewayServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = apigateway_v1.DeleteGatewayRequest(
@@ -719,7 +745,7 @@ class ApiGatewayServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -786,7 +812,8 @@ class ApiGatewayServiceAsyncClient:
                 maximum=60.0,
                 multiplier=2,
                 predicate=retries.if_exception_type(
-                    core_exceptions.ServiceUnavailable, core_exceptions.Unknown,
+                    core_exceptions.ServiceUnavailable,
+                    core_exceptions.Unknown,
                 ),
                 deadline=60.0,
             ),
@@ -801,7 +828,12 @@ class ApiGatewayServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -829,9 +861,9 @@ class ApiGatewayServiceAsyncClient:
 
             from google.cloud import apigateway_v1
 
-            def sample_list_apis():
+            async def sample_list_apis():
                 # Create a client
-                client = apigateway_v1.ApiGatewayServiceClient()
+                client = apigateway_v1.ApiGatewayServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = apigateway_v1.ListApisRequest(
@@ -842,7 +874,7 @@ class ApiGatewayServiceAsyncClient:
                 page_result = client.list_apis(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -903,12 +935,20 @@ class ApiGatewayServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListApisAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -929,9 +969,9 @@ class ApiGatewayServiceAsyncClient:
 
             from google.cloud import apigateway_v1
 
-            def sample_get_api():
+            async def sample_get_api():
                 # Create a client
-                client = apigateway_v1.ApiGatewayServiceClient()
+                client = apigateway_v1.ApiGatewayServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = apigateway_v1.GetApiRequest(
@@ -939,7 +979,7 @@ class ApiGatewayServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_api(request=request)
+                response = await client.get_api(request=request)
 
                 # Handle the response
                 print(response)
@@ -999,7 +1039,12 @@ class ApiGatewayServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1021,9 +1066,9 @@ class ApiGatewayServiceAsyncClient:
 
             from google.cloud import apigateway_v1
 
-            def sample_create_api():
+            async def sample_create_api():
                 # Create a client
-                client = apigateway_v1.ApiGatewayServiceClient()
+                client = apigateway_v1.ApiGatewayServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = apigateway_v1.CreateApiRequest(
@@ -1036,7 +1081,7 @@ class ApiGatewayServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1110,7 +1155,8 @@ class ApiGatewayServiceAsyncClient:
                 maximum=60.0,
                 multiplier=2,
                 predicate=retries.if_exception_type(
-                    core_exceptions.ServiceUnavailable, core_exceptions.Unknown,
+                    core_exceptions.ServiceUnavailable,
+                    core_exceptions.Unknown,
                 ),
                 deadline=60.0,
             ),
@@ -1125,7 +1171,12 @@ class ApiGatewayServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1154,9 +1205,9 @@ class ApiGatewayServiceAsyncClient:
 
             from google.cloud import apigateway_v1
 
-            def sample_update_api():
+            async def sample_update_api():
                 # Create a client
-                client = apigateway_v1.ApiGatewayServiceClient()
+                client = apigateway_v1.ApiGatewayServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = apigateway_v1.UpdateApiRequest(
@@ -1167,7 +1218,7 @@ class ApiGatewayServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1235,7 +1286,8 @@ class ApiGatewayServiceAsyncClient:
                 maximum=60.0,
                 multiplier=2,
                 predicate=retries.if_exception_type(
-                    core_exceptions.ServiceUnavailable, core_exceptions.Unknown,
+                    core_exceptions.ServiceUnavailable,
+                    core_exceptions.Unknown,
                 ),
                 deadline=60.0,
             ),
@@ -1250,7 +1302,12 @@ class ApiGatewayServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1278,9 +1335,9 @@ class ApiGatewayServiceAsyncClient:
 
             from google.cloud import apigateway_v1
 
-            def sample_delete_api():
+            async def sample_delete_api():
                 # Create a client
-                client = apigateway_v1.ApiGatewayServiceClient()
+                client = apigateway_v1.ApiGatewayServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = apigateway_v1.DeleteApiRequest(
@@ -1292,7 +1349,7 @@ class ApiGatewayServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1359,7 +1416,8 @@ class ApiGatewayServiceAsyncClient:
                 maximum=60.0,
                 multiplier=2,
                 predicate=retries.if_exception_type(
-                    core_exceptions.ServiceUnavailable, core_exceptions.Unknown,
+                    core_exceptions.ServiceUnavailable,
+                    core_exceptions.Unknown,
                 ),
                 deadline=60.0,
             ),
@@ -1374,7 +1432,12 @@ class ApiGatewayServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1402,9 +1465,9 @@ class ApiGatewayServiceAsyncClient:
 
             from google.cloud import apigateway_v1
 
-            def sample_list_api_configs():
+            async def sample_list_api_configs():
                 # Create a client
-                client = apigateway_v1.ApiGatewayServiceClient()
+                client = apigateway_v1.ApiGatewayServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = apigateway_v1.ListApiConfigsRequest(
@@ -1415,7 +1478,7 @@ class ApiGatewayServiceAsyncClient:
                 page_result = client.list_api_configs(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -1476,12 +1539,20 @@ class ApiGatewayServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListApiConfigsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1502,9 +1573,9 @@ class ApiGatewayServiceAsyncClient:
 
             from google.cloud import apigateway_v1
 
-            def sample_get_api_config():
+            async def sample_get_api_config():
                 # Create a client
-                client = apigateway_v1.ApiGatewayServiceClient()
+                client = apigateway_v1.ApiGatewayServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = apigateway_v1.GetApiConfigRequest(
@@ -1512,7 +1583,7 @@ class ApiGatewayServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_api_config(request=request)
+                response = await client.get_api_config(request=request)
 
                 # Handle the response
                 print(response)
@@ -1573,7 +1644,12 @@ class ApiGatewayServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1592,14 +1668,13 @@ class ApiGatewayServiceAsyncClient:
         r"""Creates a new ApiConfig in a given project and
         location.
 
-
         .. code-block:: python
 
             from google.cloud import apigateway_v1
 
-            def sample_create_api_config():
+            async def sample_create_api_config():
                 # Create a client
-                client = apigateway_v1.ApiGatewayServiceClient()
+                client = apigateway_v1.ApiGatewayServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = apigateway_v1.CreateApiConfigRequest(
@@ -1612,7 +1687,7 @@ class ApiGatewayServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1685,7 +1760,8 @@ class ApiGatewayServiceAsyncClient:
                 maximum=60.0,
                 multiplier=2,
                 predicate=retries.if_exception_type(
-                    core_exceptions.ServiceUnavailable, core_exceptions.Unknown,
+                    core_exceptions.ServiceUnavailable,
+                    core_exceptions.Unknown,
                 ),
                 deadline=60.0,
             ),
@@ -1700,7 +1776,12 @@ class ApiGatewayServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1729,9 +1810,9 @@ class ApiGatewayServiceAsyncClient:
 
             from google.cloud import apigateway_v1
 
-            def sample_update_api_config():
+            async def sample_update_api_config():
                 # Create a client
-                client = apigateway_v1.ApiGatewayServiceClient()
+                client = apigateway_v1.ApiGatewayServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = apigateway_v1.UpdateApiConfigRequest(
@@ -1742,7 +1823,7 @@ class ApiGatewayServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1809,7 +1890,8 @@ class ApiGatewayServiceAsyncClient:
                 maximum=60.0,
                 multiplier=2,
                 predicate=retries.if_exception_type(
-                    core_exceptions.ServiceUnavailable, core_exceptions.Unknown,
+                    core_exceptions.ServiceUnavailable,
+                    core_exceptions.Unknown,
                 ),
                 deadline=60.0,
             ),
@@ -1826,7 +1908,12 @@ class ApiGatewayServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1854,9 +1941,9 @@ class ApiGatewayServiceAsyncClient:
 
             from google.cloud import apigateway_v1
 
-            def sample_delete_api_config():
+            async def sample_delete_api_config():
                 # Create a client
-                client = apigateway_v1.ApiGatewayServiceClient()
+                client = apigateway_v1.ApiGatewayServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = apigateway_v1.DeleteApiConfigRequest(
@@ -1868,7 +1955,7 @@ class ApiGatewayServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1935,7 +2022,8 @@ class ApiGatewayServiceAsyncClient:
                 maximum=60.0,
                 multiplier=2,
                 predicate=retries.if_exception_type(
-                    core_exceptions.ServiceUnavailable, core_exceptions.Unknown,
+                    core_exceptions.ServiceUnavailable,
+                    core_exceptions.Unknown,
                 ),
                 deadline=60.0,
             ),
@@ -1950,7 +2038,12 @@ class ApiGatewayServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
