@@ -16,18 +16,18 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -36,12 +36,14 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.apigateway_v1.services.api_gateway_service import pagers
-from google.cloud.apigateway_v1.types import apigateway
 from google.protobuf import empty_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import ApiGatewayServiceTransport, DEFAULT_CLIENT_INFO
+
+from google.cloud.apigateway_v1.services.api_gateway_service import pagers
+from google.cloud.apigateway_v1.types import apigateway
+
+from .transports.base import DEFAULT_CLIENT_INFO, ApiGatewayServiceTransport
 from .transports.grpc import ApiGatewayServiceGrpcTransport
 from .transports.grpc_asyncio import ApiGatewayServiceGrpcAsyncIOTransport
 
@@ -61,7 +63,8 @@ class ApiGatewayServiceClientMeta(type):
     _transport_registry["grpc_asyncio"] = ApiGatewayServiceGrpcAsyncIOTransport
 
     def get_transport_class(
-        cls, label: str = None,
+        cls,
+        label: str = None,
     ) -> Type[ApiGatewayServiceTransport]:
         """Returns an appropriate transport class.
 
@@ -169,10 +172,14 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         return self._transport
 
     @staticmethod
-    def api_path(project: str, api: str,) -> str:
+    def api_path(
+        project: str,
+        api: str,
+    ) -> str:
         """Returns a fully-qualified api string."""
         return "projects/{project}/locations/global/apis/{api}".format(
-            project=project, api=api,
+            project=project,
+            api=api,
         )
 
     @staticmethod
@@ -184,10 +191,16 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def api_config_path(project: str, api: str, api_config: str,) -> str:
+    def api_config_path(
+        project: str,
+        api: str,
+        api_config: str,
+    ) -> str:
         """Returns a fully-qualified api_config string."""
         return "projects/{project}/locations/global/apis/{api}/configs/{api_config}".format(
-            project=project, api=api, api_config=api_config,
+            project=project,
+            api=api,
+            api_config=api_config,
         )
 
     @staticmethod
@@ -200,10 +213,16 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def gateway_path(project: str, location: str, gateway: str,) -> str:
+    def gateway_path(
+        project: str,
+        location: str,
+        gateway: str,
+    ) -> str:
         """Returns a fully-qualified gateway string."""
         return "projects/{project}/locations/{location}/gateways/{gateway}".format(
-            project=project, location=location, gateway=gateway,
+            project=project,
+            location=location,
+            gateway=gateway,
         )
 
     @staticmethod
@@ -216,9 +235,13 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def managed_service_path(service: str,) -> str:
+    def managed_service_path(
+        service: str,
+    ) -> str:
         """Returns a fully-qualified managed_service string."""
-        return "services/{service}".format(service=service,)
+        return "services/{service}".format(
+            service=service,
+        )
 
     @staticmethod
     def parse_managed_service_path(path: str) -> Dict[str, str]:
@@ -227,10 +250,14 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def service_path(service: str, config: str,) -> str:
+    def service_path(
+        service: str,
+        config: str,
+    ) -> str:
         """Returns a fully-qualified service string."""
         return "services/{service}/configs/{config}".format(
-            service=service, config=config,
+            service=service,
+            config=config,
         )
 
     @staticmethod
@@ -240,10 +267,14 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def service_account_path(project: str, service_account: str,) -> str:
+    def service_account_path(
+        project: str,
+        service_account: str,
+    ) -> str:
         """Returns a fully-qualified service_account string."""
         return "projects/{project}/serviceAccounts/{service_account}".format(
-            project=project, service_account=service_account,
+            project=project,
+            service_account=service_account,
         )
 
     @staticmethod
@@ -256,7 +287,9 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -269,9 +302,13 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -280,9 +317,13 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -291,9 +332,13 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -302,10 +347,14 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -568,12 +617,20 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListGatewaysPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -668,7 +725,12 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -687,7 +749,6 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         r"""Creates a new Gateway in a given project and
         location.
 
-
         .. code-block:: python
 
             from google.cloud import apigateway_v1
@@ -792,7 +853,12 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -915,7 +981,12 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1030,7 +1101,12 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1132,12 +1208,20 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListApisPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1228,7 +1312,12 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1345,7 +1434,12 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1461,7 +1555,12 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1576,7 +1675,12 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1678,12 +1782,20 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListApiConfigsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1775,7 +1887,12 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1794,7 +1911,6 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         r"""Creates a new ApiConfig in a given project and
         location.
 
-
         .. code-block:: python
 
             from google.cloud import apigateway_v1
@@ -1893,7 +2009,12 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -2010,7 +2131,12 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -2125,7 +2251,12 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
